# ThermalNetwork Documentation

A library for sizing multiple ground heat exchangers distributed around a single-pipe thermal network.

The primary entry point is through the CLI, intended to be used with [URBANopt](https://docs.urbanopt.net/). In the course of a typical UO workflow, sizing a Ground-source Heat Pump (GHP) is done with [this command](https://docs.urbanopt.net/workflows/ghp/ghp.html#size-ghp).

It is possible to access the CLI directly. Once this package has been installed successfully, the available commands may be seen with `thermalnetwork --help`.
